Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(641)

Unified Diff: net/spdy/spdy_protocol.cc

Issue 851503003: Update from https://crrev.com/311076 (Closed) Base URL: git@github.com:domokit/mojo.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/spdy/spdy_network_transaction_unittest.cc ('k') | net/spdy/spdy_read_queue.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/spdy/spdy_protocol.cc
diff --git a/net/spdy/spdy_protocol.cc b/net/spdy/spdy_protocol.cc
index bf33d43944ab4460694ea588fe9ab6a3370c049a..a0e83132d039411838708adf3bb71e5d6b4f2d41 100644
--- a/net/spdy/spdy_protocol.cc
+++ b/net/spdy/spdy_protocol.cc
@@ -542,9 +542,9 @@ bool SpdyConstants::IsValidGoAwayStatus(SpdyMajorVersion version,
return false;
}
// GOAWAY_INADEQUATE_SECURITY is the last valid status.
if (goaway_status_field >
- SerializeGoAwayStatus(version, GOAWAY_INADEQUATE_SECURITY)) {
+ SerializeGoAwayStatus(version, GOAWAY_HTTP_1_1_REQUIRED)) {
return false;
}
« no previous file with comments | « net/spdy/spdy_network_transaction_unittest.cc ('k') | net/spdy/spdy_read_queue.cc » ('j') | no next file with comments »
@@ -542,9 +542,9 @@ bool SpdyConstants::IsValidGoAwayStatus(SpdyMajorVersion version,
return false;
}
- // GOAWAY_INADEQUATE_SECURITY is the last valid status.
+ // GOAWAY_HTTP_1_1_REQUIRED is the last valid status.
if (goaway_status_field >

Powered by Google App Engine
This is Rietveld 408576698